@@ -23,7 +23,9 @@ describe('Plugin', () => {
       };
 
       if (fileExists(optionsPath)) {
-        options.plugins = [[plugin, require(optionsPath)]];
+        const opts = require(optionsPath);
+        options.plugins = [[plugin, opts]];
+        options.moduleId = opts.moduleName;
       }
 
       if (fileExists(exceptionPath)) {
@@ -35,7 +37,7 @@ describe('Plugin', () => {
       } else {
         const actual = transformFileSync(actualPath, options).code;
         const expected = fs.readFileSync(
-            path.join(fixtureDir, 'expected.js')
+          path.join(fixtureDir, 'expected.js')
         ).toString();
 
         assert.equal(trim(actual), trim(expected));
